@@ -10,6 +10,7 @@ from collections import defaultdict
 from pdfminer.high_level import extract_text
 from fabric.connection import Connection
 
+from wbtools.db.afp import WBAFPDBManager
 from wbtools.db.paper import WBPaperDBManager
 from wbtools.lib.nlp.common import EntityType, EntityExtractionType, ExtractedEntity
 from wbtools.lib.nlp.entity_extraction.email_addresses import get_email_addresses_from_text
@@ -85,9 +86,10 @@ class WBPaper(object):
     """WormBase paper information"""
 
     def __init__(self, paper_id: str = '', main_text: str = '', ocr_text: str = '', temp_text: str = '',
-                 aut_text: str = '', html_text: str = '', supplemental_docs: list = None, tazendra_ssh_user: str = '',
-                 tazendra_ssh_passwd: str = '', title: str = '', journal: str = '', pub_date: str = '',
-                 authors: List[WBAuthor] = None, abstract: str = '', db_manager: WBPaperDBManager = None):
+                 aut_text: str = '', html_text: str = '', proof_text: str = '', supplemental_docs: list = None,
+                 tazendra_ssh_user: str = '', tazendra_ssh_passwd: str = '', title: str = '', journal: str = '',
+                 pub_date: str = '', authors: List[WBAuthor] = None, abstract: str = '',
+                 db_manager: WBPaperDBManager = None):
         self.paper_id = paper_id
         self.title = title
         self.journal = journal
@@ -99,10 +101,14 @@ class WBPaper(object):
         self.temp_text = temp_text
         self.aut_text = aut_text
         self.html_text = html_text
+        self.proof_text = proof_text
         self.supplemental_docs = supplemental_docs if supplemental_docs else []
         self.aut_class_values = defaultdict(str)
         self.paper_file_reader = PaperFileReader(tazendra_ssh_user=tazendra_ssh_user,
                                                  tazendra_ssh_passwd=tazendra_ssh_passwd)
+        self.afp_final_submission = False
+        self.afp_processed = False
+        self.afp_partial_submission = False
         self.db_manager = db_manager
 
     def get_corresponding_author(self):
@@ -132,10 +138,11 @@ class WBPaper(object):
 
         Returns:
             list: a list of documents, which can be strings or lists of strings or list of lists of strings according to
-                  the combination of tokenization arguments passed
+                  the provided combination of tokenization arguments
         """
         docs = [self.main_text if self.main_text else self.html_text if self.html_text else self.ocr_text if
-                self.ocr_text else self.aut_text if self.aut_text else self.temp_text]
+                self.ocr_text else self.aut_text if self.aut_text else self.temp_text if self.temp_text else
+                self.proof_text]
         if include_supplemental:
             docs.extend(self.supplemental_docs)
         docs = [d for doc in docs for d in get_documents_from_text(
@@ -189,6 +196,8 @@ class WBPaper(object):
                         dir_path, filename, remote_file, pdf))
                 elif "ocr" in additional_options:
                     self.ocr_text = self.paper_file_reader.get_text_from_file(dir_path, filename, remote_file, pdf)
+                elif "temp_proof" in additional_options:
+                    self.proof_text = self.paper_file_reader.get_text_from_file(dir_path, filename, remote_file, pdf)
                 elif "temp" in additional_options:
                     self.temp_text = self.paper_file_reader.get_text_from_file(dir_path, filename, remote_file, pdf)
                 elif "aut" in additional_options:
@@ -230,6 +239,26 @@ class WBPaper(object):
         else:
             raise Exception("PaperDBManager not set")
 
+    def load_afp_info_from_db(self, paper_ids_no_submission: List[str] = None,
+                              paper_ids_full_submission: List[str] = None,
+                              paper_ids_partial_submission: List[str] = None):
+        """load AFP data from WormBase database"""
+        if not paper_ids_no_submission or not paper_ids_full_submission or not paper_ids_partial_submission:
+            if self.db_manager:
+                afp_db_manager = self.db_manager.get_db_manager(cls=WBAFPDBManager)
+                if not paper_ids_no_submission:
+                    paper_ids_no_submission = afp_db_manager.get_paper_ids_afp_no_submission()
+                if not paper_ids_full_submission:
+                    paper_ids_full_submission = afp_db_manager.get_paper_ids_afp_full_submission()
+                if not paper_ids_partial_submission:
+                    paper_ids_partial_submission = afp_db_manager.get_paper_ids_afp_partial_submission()
+            else:
+                raise Exception("PaperDBManager not set")
+        self.afp_processed = self.paper_id in (set(paper_ids_no_submission) | set(paper_ids_full_submission) |
+                                               set(paper_ids_full_submission))
+        self.afp_partial_submission = self.paper_id in paper_ids_partial_submission
+        self.afp_final_submission = self.paper_id in paper_ids_full_submission
+
     def has_same_wbpaper_id_as_filename(self, filename):
         return self._get_matches_from_filename(filename)[0] == self.paper_id
 
@@ -247,7 +276,8 @@ class WBPaper(object):
         Returns:
             bool: whether the paper has a temporary pdf file
         """
-        return not self.main_text
+        return self.main_text is None and self.html_text is None and self.html_text is None and self.ocr_text is None \
+            and self.aut_text is None and self.temp_text is None
 
     def has_supplementary_material(self):
         """determine if the paper has supplemental material associated to it
